@@ -10,7 +10,10 @@ pub mod typography;
 
 use crate::TailwindInstance;
 use nom::{bytes::complete::tag, Err, IResult};
-use std::fmt::{Debug, Display, Formatter};
+use std::{
+    collections::HashMap,
+    fmt::{Debug, Display, Formatter},
+};
 
 #[derive(Debug)]
 pub struct TailwindObject {
